==> php82-nextcloud-28.0.6.tgz: share/nextcloud/apps/serverinfo/l10n/nl.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU info niet beschikbaar",
    "Load average: {cpu} (last minute)" : "Gemiddelde belasting: {cpu} (laatste minuut)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Totaal: {memTotalBytes}/Huidig gebruik: {memUsageBytes}",
    "RAM info not available" : "RAM-info niet beschikbaar",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Totaal: {swapTotalBytes}/Huidig gebruik: {swapUsageBytes}",
    "SWAP info not available" : "SWAP-info niet beschikbaar",
    "Copied!" : "Gekopieerd!",
    "Not supported!" : "Niet ondersteund",
    "Press ⌘-C to copy." : "Druk op ⌘-C om te kopiëren.",
    "Press Ctrl-C to copy." : "Druk op Ctrl-C om te kopiëren.",
    "System" : "Systeem",
    "Monitoring" : "Monitoren",
    "Monitoring app with useful server information" : "Monitor app met nuttige serverinformatie",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Toont nuttige serverinformatie, zoals CPU belasting, RAM gebruik, disk gebruik, aantal gebruikers, etc.",
    "Operating System:" : "Besturingssysteem:",
    "CPU:" : "CPU:",
    "Unknown Processor" : "Onbekende Processor",
    "Memory:" : "Geheugen:",
    "Server time:" : "Servertijd:",
    "Uptime:" : "Bedrijfstijd:",
    "Temperature" : "Temperatuur",
    "Load" : "Belasting",
    "Memory" : "Geheugen",
    "Disk" : "Schijf",
    "Mount:" : "Koppelpunt:",
    "Filesystem:" : "Bestandssysteem:",
    "Size:" : "Grootte:",
    "Available:" : "Beschikbaar:",
    "Used:" : "Gebruikt:",
    "Files:" : "Bestanden:",
    "Storages:" : "Opslag:",
    "Free Space:" : "Vrije ruimte:",
    "Network" : "Netwerk",
    "Hostname:" : "Hostname:",
    "DNS:" : "DNS:",
    "Gateway:" : "Gateway:",
    "Status:" : "Status:",
    "Speed:" : "Snelheid:",
    "Duplex:" : "Duplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Actieve gebruikers",
    "Total users:" : "Totaal aantal gebruikers:",
    "24 hours:" : "24 uur:",
    "1 hour:" : "1 uur:",
    "5 mins:" : "5 min.:",
    "Shares" : "Delen",
    "Users:" : "Gebruikers:",
    "Groups:" : "Groepen:",
    "Links:" : "Links:",
    "Emails:" : "Emails:",
    "Federated sent:" : "Federated verstuurd:",
    "Federated received:" : "Federated ontvangen:",
    "Talk conversations:" : "Talk gesprekken:",
    "PHP" : "PHP",
    "Version:" : "Versie:",
    "Memory limit:" : "Geheugen limiet:",
    "Max execution time:" : "Maximale uitvoeringstijd:",
    "Upload max size:" : "Max. uploadgrootte:",
    "OPcache Revalidate Frequency:" : "Frequentie OPcache opnieuw valideren:",
    "Extensions:" : "Extensies:",
    "Unable to list extensions" : "Kan extensies niet weergeven",
    "Show phpinfo" : "phpinfo weergeven",
    "Database" : "Database",
    "Type:" : "Type:",
    "External monitoring tool" : "Externe monitoring tool",
    "Use this end point to connect an external monitoring tool:" : "Gebruik dit eindpunt om een extern monitoringprogramma te koppelen:",
    "Copy" : "Kopiëren",
    "Output in JSON" : "Uitvoer in JSON",
    "Skip app updates (including app updates will send an external request to the app store)" : "App-updates overslaan (bij inclusief app-updates wordt een extern verzoek naar de app store gestuurd)",
    "Skip server update" : "Serverupdate overslaan",
    "To use an access token, please generate one then set it using the following command:" : "Om een ​​toegangstoken te gebruiken, genereert u er een en stelt u deze in met de volgende opdracht:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Geef vervolgens het token met de \"NC-Token\" -header door bij het opvragen van de bovenstaande URL."
},
"nplurals=2; plural=(n != 1);");

==> php82-nextcloud-30.0.11.tgz: share/nextcloud/apps/serverinfo/l10n/nl.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU info niet beschikbaar",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Totaal: {memTotalBytes}/Huidig gebruik: {memUsageBytes}",
    "RAM info not available" : "RAM-info niet beschikbaar",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Totaal: {swapTotalBytes}/Huidig gebruik: {swapUsageBytes}",
    "SWAP info not available" : "SWAP-info niet beschikbaar",
    "Copied!" : "Gekopieerd!",
    "Not supported!" : "Niet ondersteund",
    "Press ⌘-C to copy." : "Druk op ⌘-C om te kopiëren.",
    "Press Ctrl-C to copy." : "Druk op Ctrl-C om te kopiëren.",
    "System" : "Systeem",
    "Monitoring" : "Monitoren",
    "Monitoring app with useful server information" : "Monitor app met nuttige serverinformatie",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Toont nuttige serverinformatie, zoals CPU belasting, RAM gebruik, disk gebruik, aantal gebruikers, etc.",
    "Operating System:" : "Besturingssysteem:",
    "CPU:" : "CPU:",
    "Unknown Processor" : "Onbekende Processor",
    "Memory:" : "Geheugen:",
    "Server time:" : "Servertijd:",
    "Uptime:" : "Bedrijfstijd:",
    "Temperature" : "Temperatuur",
    "Load" : "Belasting",
    "Memory" : "Geheugen",
    "Disk" : "Schijf",
    "Mount:" : "Koppelpunt:",
    "Filesystem:" : "Bestandssysteem:",
    "Size:" : "Grootte:",
    "Available:" : "Beschikbaar:",
    "Used:" : "Gebruikt:",
    "Files:" : "Bestanden:",
    "Storages:" : "Opslag:",
    "Free Space:" : "Vrije ruimte:",
    "Network" : "Netwerk",
    "Hostname:" : "Hostname:",
    "Gateway:" : "Gateway:",
    "Status:" : "Status:",
    "Speed:" : "Snelheid:",
    "Duplex:" : "Duplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Actieve gebruikers",
    "Last hour" : "Laatste uur",
    "Shares" : "Delen",
    "Users:" : "Gebruikers:",
    "Groups:" : "Groepen:",
    "Links:" : "Links:",
    "Emails:" : "Emails:",
    "Federated sent:" : "Federated verstuurd:",
    "Federated received:" : "Federated ontvangen:",
    "Talk conversations:" : "Talk gesprekken:",
    "PHP" : "PHP",
    "Version:" : "Versie:",
    "Memory limit:" : "Geheugen limiet:",
    "Max execution time:" : "Maximale uitvoeringstijd:",
    "Upload max size:" : "Max. uploadgrootte:",
    "OPcache Revalidate Frequency:" : "Frequentie OPcache opnieuw valideren:",
    "Extensions:" : "Extensies:",
    "Unable to list extensions" : "Kan extensies niet weergeven",
    "Show phpinfo" : "phpinfo weergeven",
    "Database" : "Database",
    "Type:" : "Type:",
    "External monitoring tool" : "Externe monitoring tool",
    "Use this end point to connect an external monitoring tool:" : "Gebruik dit eindpunt om een extern monitoringprogramma te koppelen:",
    "Copy" : "Kopiëren",
    "Output in JSON" : "Uitvoer in JSON",
    "Skip server update" : "Serverupdate overslaan",
    "To use an access token, please generate one then set it using the following command:" : "Om een ​​toegangstoken te gebruiken, genereert u er een en stelt u deze in met de volgende opdracht:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Geef vervolgens het token met de \"NC-Token\" -header door bij het opvragen van de bovenstaande URL.",
    "Load average: {cpu} (last minute)" : "Gemiddelde belasting: {cpu} (laatste minuut)",
    "DNS:" : "DNS:",
    "Total users:" : "Totaal aantal gebruikers:",
    "24 hours:" : "24 uur:",
    "1 hour:" : "1 uur:",
    "5 mins:" : "5 min.:"
},
"nplurals=2; plural=(n != 1);");
